@@ -4,6 +4,7 @@ from functools import reduce
 
 import numpy as np
 import pandas as pd
+import matplotlib.pylab as plt
 import altair as alt
 from sklearn.metrics import pairwise_distances
 from sklearn.metrics.pairwise import paired_distances
@@ -305,6 +306,8 @@ class EmbeddingSet:
             name: name of the property to add
             func: function that receives an embedding and needs to output the property value
 
+        Usage:
+
         ```python
         from whatlies.embeddingset import EmbeddingSet
 
@@ -326,6 +329,8 @@ class EmbeddingSet:
         Arguments:
             name: manually specify the name of the average embedding
 
+        Usage:
+
         ```python
         from whatlies.embeddingset import EmbeddingSet
 
@@ -341,7 +346,7 @@ class EmbeddingSet:
         x = np.array([v.vector for v in self.embeddings.values()])
         return Embedding(name, np.mean(x, axis=0))
 
-    def embset_similar(self, emb: Union[str, Embedding], n: int = 10, metric='cosine'):
+    def embset_similar(self, emb: Union[str, Embedding], n: int = 10, metric="cosine"):
         """
         Retreive an [EmbeddingSet][whatlies.embeddingset.EmbeddingSet] that are the most simmilar to the passed query.
 
@@ -356,7 +361,7 @@ class EmbeddingSet:
         embs = [w[0] for w in self.score_similar(emb, n, metric)]
         return EmbeddingSet({w.name: w for w in embs})
 
-    def score_similar(self, emb: Union[str, Embedding], n: int = 10, metric='cosine'):
+    def score_similar(self, emb: Union[str, Embedding], n: int = 10, metric="cosine"):
         """
         Retreive a list of (Embedding, score) tuples that are the most similar to the passed query.
 
@@ -369,10 +374,14 @@ class EmbeddingSet:
             An list of ([Embedding][whatlies.embedding.Embedding], score) tuples.
         """
         if n > len(self):
-            raise ValueError(f"You cannot retreive (n={n}) more items than exist in the Embeddingset (len={len(self)})")
+            raise ValueError(
+                f"You cannot retreive (n={n}) more items than exist in the Embeddingset (len={len(self)})"
+            )
 
         if str(emb) not in self.embeddings.keys():
-            raise ValueError(f"Embedding for `{str(emb)}` does not exist in this EmbeddingSet")
+            raise ValueError(
+                f"Embedding for `{str(emb)}` does not exist in this EmbeddingSet"
+            )
 
         if isinstance(emb, str):
             emb = self[emb]
@@ -385,28 +394,63 @@ class EmbeddingSet:
         return [(self[q], float(d)) for q, d in by_similarity[:n]]
 
     def to_matrix(self):
-        return np.array([w.vector for w in self.embeddings.values()])
+        """
+        Does exactly the same as `.to_X`. It takes the embedding vectors and turns it into a numpy array.
+        """
+        return self.to_X()
+
+    def to_dataframe(self):
+        """
+        Turns the embeddingset into a pandas dataframe.
+        """
+        mat = self.to_matrix()
+        return pd.DataFrame(mat, index=list(self.embeddings.keys()))
 
     def movement_df(self, other, metric="euclidean"):
+        """
+        Creates a dataframe that shows the movement from one embeddingset to another one.
+
+        Arguments:
+            other: the other embeddingset to compare against, will only keep the overlap
+            metric: metric to use to calculate movement, must be scipy or sklearn compatible
+
+        Usage:
+
+        ```python
+        from whatlies.language import SpacyLanguage
+        lang1 = SpacyLanguage("en_core_web_sm")
+        lang2 = SpacyLanguage("en_core_web_md")
+
+        names = ['red', 'blue', 'green', 'yellow', 'cat', 'dog', 'mouse', 'rat', 'bike', 'car']
+        emb1 = lang1[names]
+        emb2 = lang2[names]
+        emb1.movement_df(emb2)
+        ```
+        """
         overlap = list(set(self.embeddings.keys()).union(set(other.embeddings.keys())))
         mat1 = np.array([w.vector for w in self[overlap]])
         mat2 = np.array([w.vector for w in other[overlap]])
-        return pd.DataFrame({
-            'name': overlap,
-            'movement': paired_distances(mat1, mat2, metric)
-        }).sort_values(['movement'], ascending=False).reset_index()
+        return (
+            pd.DataFrame(
+                {"name": overlap, "movement": paired_distances(mat1, mat2, metric)}
+            )
+            .sort_values(["movement"], ascending=False)
+            .reset_index()
+        )
 
     def to_axis_df(self, x_axis, y_axis):
         if isinstance(x_axis, str):
             x_axis = self[x_axis]
         if isinstance(y_axis, str):
             y_axis = self[y_axis]
-        return pd.DataFrame({
-            "x_axis": self.compare_against(x_axis),
-            "y_axis": self.compare_against(y_axis),
-            "name": [v.name for v in self.embeddings.values()],
-            "original": [v.orig for v in self.embeddings.values()],
-        })
+        return pd.DataFrame(
+            {
+                "x_axis": self.compare_against(x_axis),
+                "y_axis": self.compare_against(y_axis),
+                "name": [v.name for v in self.embeddings.values()],
+                "original": [v.orig for v in self.embeddings.values()],
+            }
+        )
 
     def plot(
         self,
@@ -442,7 +486,45 @@ class EmbeddingSet:
         plot_graph_layout(self.embeddings, kind, **kwargs)
         return self
 
-    def plot_movement(self, other,
+    def plot_correlation(self, metric=None):
+        """
+        Make a correlation plot. Shows you the correlation between all the word embeddings. Can
+        also be configured to show distances instead.
+
+        Arguments:
+            metric: don't plot correlation but a distance measure, must be scipy compatible (cosine, euclidean, etc)
+
+        Usage:
+
+        ```python
+        from whatlies.language import SpacyLanguage
+        lang = SpacyLanguage("en_core_web_md")
+
+        names = ['red', 'blue', 'green', 'yellow', 'cat', 'dog', 'mouse', 'rat', 'bike', 'car']
+        emb = lang[names]
+        emb.plot_correlation()
+        ```
+
+        ![](https://rasahq.github.io/whatlies/images/corrplot.png)
+        """
+        df = self.to_dataframe().T
+        corr_df = (
+            pairwise_distances(self.to_matrix(), metric=metric) if metric else df.corr()
+        )
+
+        fig, ax = plt.subplots()
+        plt.imshow(corr_df)
+        plt.xticks(range(len(df.columns)), df.columns)
+        plt.yticks(range(len(df.columns)), df.columns)
+        plt.colorbar()
+
+        # Rotate the tick labels and set their alignment.
+        plt.setp(ax.get_xticklabels(), rotation=90, ha="right", rotation_mode="anchor")
+        plt.show()
+
+    def plot_movement(
+        self,
+        other,
         x_axis: Union[str, Embedding],
         y_axis: Union[str, Embedding],
         first_group_name="before",
@@ -483,32 +565,46 @@ class EmbeddingSet:
         if isinstance(y_axis, str):
             y_axis = self[y_axis]
 
-        df1 = (self.to_axis_df(x_axis, y_axis)
-               .set_index('original')
-               .drop(columns=['name']))
-        df2 = (other.to_axis_df(x_axis, y_axis)
-               .set_index('original')
-               .drop(columns=['name'])
-               .loc[lambda d: d.index.isin(df1.index)])
-        df_draw = (pd.concat([df1, df2])
-                   .reset_index()
-                   .sort_values(['original'])
-                   .assign(constant=1))
+        df1 = (
+            self.to_axis_df(x_axis, y_axis).set_index("original").drop(columns=["name"])
+        )
+        df2 = (
+            other.to_axis_df(x_axis, y_axis)
+            .set_index("original")
+            .drop(columns=["name"])
+            .loc[lambda d: d.index.isin(df1.index)]
+        )
+        df_draw = (
+            pd.concat([df1, df2])
+            .reset_index()
+            .sort_values(["original"])
+            .assign(constant=1)
+        )
 
         plots = []
-        for idx, grp_df in df_draw.groupby('original'):
-            _ = (alt.Chart(grp_df)
-                 .mark_line(color="gray", strokeDash=[2, 1])
-                 .encode(x='x_axis:Q', y='y_axis:Q'))
+        for idx, grp_df in df_draw.groupby("original"):
+            _ = (
+                alt.Chart(grp_df)
+                .mark_line(color="gray", strokeDash=[2, 1])
+                .encode(x="x_axis:Q", y="y_axis:Q")
+            )
             plots.append(_)
         p0 = reduce(lambda x, y: x + y, plots)
 
-        p1 = (deepcopy(self)
-              .add_property("group", lambda d: first_group_name)
-              .plot_interactive(x_axis, y_axis, annot=annot, show_axis_point=True, color="group"))
-        p2 = (deepcopy(other)
-              .add_property("group", lambda d: second_group_name)
-              .plot_interactive(x_axis, y_axis, annot=annot, show_axis_point=True, color="group"))
+        p1 = (
+            deepcopy(self)
+            .add_property("group", lambda d: first_group_name)
+            .plot_interactive(
+                x_axis, y_axis, annot=annot, show_axis_point=True, color="group"
+            )
+        )
+        p2 = (
+            deepcopy(other)
+            .add_property("group", lambda d: second_group_name)
+            .plot_interactive(
+                x_axis, y_axis, annot=annot, show_axis_point=True, color="group"
+            )
+        )
         return p0 + p1 + p2
 
     def plot_interactive(
@@ -550,15 +646,20 @@ class EmbeddingSet:
         if isinstance(y_axis, str):
             y_axis = self[y_axis]
 
-        plot_df = pd.DataFrame({
-            "x_axis": self.compare_against(x_axis),
-            "y_axis": self.compare_against(y_axis),
-            "name": [v.name for v in self.embeddings.values()],
-            "original": [v.orig for v in self.embeddings.values()],
-        })
+        plot_df = pd.DataFrame(
+            {
+                "x_axis": self.compare_against(x_axis),
+                "y_axis": self.compare_against(y_axis),
+                "name": [v.name for v in self.embeddings.values()],
+                "original": [v.orig for v in self.embeddings.values()],
+            }
+        )
 
         if color:
-            plot_df[color] = [getattr(v, color) if hasattr(v, color) else '' for v in self.embeddings.values()]
+            plot_df[color] = [
+                getattr(v, color) if hasattr(v, color) else ""
+                for v in self.embeddings.values()
+            ]
 
         if not show_axis_point:
             plot_df = plot_df.loc[lambda d: ~d["name"].isin([x_axis.name, y_axis.name])]
